@@ -4,14 +4,17 @@
  * Author:    
  */
 
-#ifndef __ABSTRACTSTORAGE_H__
-#define __ABSTRACTSTORAGE_H__
+#ifndef __LFL__SEARCH__ABSTRACTSTORAGE_H__
+#define __LFL__SEARCH__ABSTRACTSTORAGE_H__
 
 
 #include <common.h>
 #include "Rule.h"
 
 
+namespace lfl { namespace search {
+
+
 /**
  * This is an abstract storage of mined rules. The popRule() method should 
  * return rules in the order of significance of the rule (from least 
@@ -29,4 +32,5 @@ public:
     virtual void print() = 0;
 };
 
+}}
 #endif
