@@ -4,8 +4,8 @@
  * Author:    Michal Burda
  */
 
-#ifndef __UNLIMITEDSTORAGE_H__
-#define __UNLIMITEDSTORAGE_H__
+#ifndef __LFL__SEARCH__UNLIMITEDSTORAGE_H__
+#define __LFL__SEARCH__UNLIMITEDSTORAGE_H__
 
 
 #include <common.h>
@@ -13,6 +13,9 @@
 #include "RuleQueue.h"
 
 
+namespace lfl { namespace search {
+
+
 class UnlimitedStorage : public AbstractStorage {
 protected:
     size_t m_statistic;
@@ -76,4 +79,5 @@ public:
     }
 };
 
+}}
 #endif
